use serde::{
  de::{
    self,
    Unexpected,
  },
  Serializer,
  Deserializer,
  Deserialize,
}; 

/// Seiralize bool into "yes"/"no", just like the LunaNode API does.
pub fn serialize<S>(succ: &bool, serializer: S) -> Result<S::Ok, S::Error> 
where
  S: Serializer {
  match succ {
    true => serializer.serialize_str("yes"),
    false => serializer.serialize_str("no"),
  }
}

/// Deserialize bool from String with custom value mapping "yes" => true, "no" => false
pub fn deserialize<'de, D>(deserializer: D) -> Result<bool, D::Error>
where
    D: Deserializer<'de>,
{
    match String::deserialize(deserializer)?.as_ref() {
        "yes" => Ok(true),
        "no" => Ok(false),
        other => Err(de::Error::invalid_value(
            Unexpected::Str(other),
            &"\"yes\" or \"no\"",
        )),
    }
}
